REMARK TEMPLATE
REMARK CLUSTER 4_1_2
REMARK REPRESENTING 10 CATALYTIC SITES
REMARK ID 2om2_A48-A43-A200-A204-A178
REMARK MCSA_ID 533
REMARK PDB_ID 2om2
REMARK UNIPROT_ID P63096
REMARK EC None
REMARK ENZYME Guanine nucleotide-binding protein G(i), alpha-1 subunit, Regulator of G-protein signalling 14 GoLoco motif peptide
REMARK EXPERIMENTAL_METHOD X-ray diffraction
REMARK RESOLUTION 2.2
REMARK ORGANISM_NAME Homo sapiens
REMARK ORGANISM_ID 9606
ATOM      3  CA ZTHR A  48      33.911 -23.654   9.552 T     0.53 
ATOM      3  CB ZTHR A  48      34.739 -23.239   8.310 T     0.53 
ATOM      1  OG1ZTHR A  48      36.129 -23.451   8.587 T     0.53 
ATOM      3  CD ZGLU A  43      42.537 -29.462   7.690 E     2.08 
ATOM      3  OE1ZGLU A  43      42.721 -29.948   8.832 E     2.08 
ATOM      3  OE2ZGLU A  43      42.492 -28.227   7.487 E     2.08 
ATOM      0  CZ ZARG A 178      43.760 -26.926  10.370 R     2.35 
ATOM      3  NH1ZARG A 178      42.887 -26.457   9.483 R     2.35 
ATOM      3  NH2ZARG A 178      44.119 -28.202  10.324 R     2.35 
END
